Struct
MalcontentSessionLimitsBuilder
unstable since: 0.14.0
Description [src]
struct MctSessionLimitsBuilder {
/* No available fields */
}
A stack-allocated mutable structure used to build an
MctSessionLimits instance. Use
mct_session_limits_builder_init(), various method calls to set
properties of the session limits, and then
mct_session_limits_builder_end(), to construct an
MctSessionLimits.
Available since: 0.14.0
Instance methods
mct_session_limits_builder_copy
Copy the given builder to a newly-allocated
MctSessionLimitsBuilder on the heap.
since: 0.5.0
mct_session_limits_builder_end
Finish constructing an MctSessionLimits with the given
builder, and return it.
since: 0.5.0
mct_session_limits_builder_free
Free an MctSessionLimitsBuilder originally allocated using
mct_session_limits_builder_new().
since: 0.5.0
mct_session_limits_builder_init
Initialise the given builder so it can be used to construct a new
MctSessionLimits.
since: 0.5.0
mct_session_limits_builder_set_daily_limit
Set the session limits in builder to be a daily limit, where the total
active session time for the user has a given limit each day.
unstable since: 0.14.0
mct_session_limits_builder_set_daily_schedule
Set the session limits in builder to be a daily schedule, where sessions are
allowed between start_time_secs and end_time_secs every day.
unstable since: 0.14.0
mct_session_limits_builder_set_none
Unset any session limits currently set in the builder.
since: 0.5.0